@@ -9,7 +9,7 @@ from .api import API
 from .bot import Bot
 from .exception import VkErr
 from .lp import LongPoll
-from .signal import Signal, SignalsList
+from .signal import Signal, SignalsList, signal
 from .reaction import Reaction, ReactionsList
 
 
@@ -18,4 +18,4 @@ from .validators import *
 from .tools import *
 
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
